'use strict';

var designSystem = require('@wix/design-system');
var t = require('react');
var ricosContext = require('ricos-context');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var t__default = /*#__PURE__*/_interopDefaultCompat(t);

const SliderWithInput = ({
  min,
  max,
  onChange,
  label,
  sliderDataHook,
  inputDataHook,
  value,
  tooltipTextKey
}) => {
  const zIndexService = t.useContext(ricosContext.ZIndexContext);
  const inputRef = t.useRef(null);
  const [inputKey, setInputKey] = t.useState(0);
  const [inputValue, setInputValue] = t.useState(value);
  t__default.default.useEffect(() => {
    if (value !== inputValue) {
      setInputValue(value);
    }
  }, [value]);
  const handleInputWithinBounds = (data) => {
    const numberValue = Math.round(Number(data));
    const valueWithinBounds = isNaN(numberValue) || numberValue < min ? min : numberValue > max ? max : numberValue;
    setInputValue(valueWithinBounds);
    if (value !== valueWithinBounds) {
      onChange(valueWithinBounds);
      return;
    }
    setInputKey((prev) => prev + 1);
  };
  return /* @__PURE__ */ t__default.default.createElement(
    designSystem.FieldSet,
    {
      legend: label,
      legendSize: "small",
      legendPlacement: "top",
      columns: "auto 60px",
      infoContent: tooltipTextKey,
      infoTooltipProps: {
        appendTo: (el) => {
          var _a;
          return Boolean((_a = el.getAttribute("data-hook")) == null ? void 0 : _a.includes("ricos-portal"));
        },
        zIndex: zIndexService.getZIndex("TOOLTIP")
      }
    },
    /* @__PURE__ */ t__default.default.createElement(
      designSystem.Slider,
      {
        onChange: (value2) => {
          const sliderValue = typeof value2 === "number" ? value2 : value2[0];
          onChange(sliderValue);
          setInputValue(sliderValue);
        },
        min,
        max,
        value,
        displayMarks: false,
        dataHook: sliderDataHook,
        displayTooltip: false
      }
    ),
    /* @__PURE__ */ t__default.default.createElement(
      designSystem.NumberInput,
      {
        key: inputKey,
        inputRef,
        value: inputValue,
        min,
        max,
        onChange: (value2, stringValue) => {
          if (stringValue === "") {
            setInputValue("");
            return;
          }
          if (typeof value2 === "number") {
            onChange(value2);
            setInputValue(value2);
          }
        },
        size: "small",
        hideStepper: true,
        dataHook: inputDataHook,
        onBlur: (e) => handleInputWithinBounds(e.target.value),
        onKeyDown: (e) => {
          var _a;
          if (["Enter", "Esc"].includes(e.key)) {
            handleInputWithinBounds((_a = inputRef.current) == null ? void 0 : _a.value);
          }
        }
      }
    )
  );
};

exports.SliderWithInput = SliderWithInput;
//# sourceMappingURL=slider-with-input.js.map
