import { FormField, Input } from '@wix/design-system';
import t__default, { useState, useContext } from 'react';
import { RicosContext } from 'ricos-context';
import { isValidUrl } from './utils.js';
import 'wix-rich-content-common';

const LinkInput = ({
  value,
  onChange,
  placeholder,
  dataHook,
  inputRef,
  onBlur
}) => {
  const [submittedInvalidUrl, setSubmittedInvalidUrl] = useState(() => value && !isValidUrl(value));
  const { t } = useContext(RicosContext);
  const handleInputChange = (event) => {
    const value2 = event.target.value;
    setSubmittedInvalidUrl(false);
    onChange(value2);
  };
  const handleBlur = () => {
    if (value && !isValidUrl(value)) {
      setSubmittedInvalidUrl(true);
    }
    onBlur == null ? void 0 : onBlur({ url: value });
  };
  return /* @__PURE__ */ t__default.createElement(
    FormField,
    {
      status: submittedInvalidUrl ? "error" : void 0,
      statusMessage: submittedInvalidUrl ? t("LinkPanel_ErrorTooltip") : void 0,
      label: t("GalleryImageSettings_Link_Label")
    },
    /* @__PURE__ */ t__default.createElement(
      Input,
      {
        inputRef: (ref) => {
          if (inputRef) {
            inputRef.current = ref;
          }
        },
        type: "url",
        placeholder,
        value,
        onChange: handleInputChange,
        dataHook,
        onBlur: handleBlur
      }
    )
  );
};

export { LinkInput };
//# sourceMappingURL=link-input.js.map
