import { FillButtonUniDriver, FillPreviewUniDriver, TextButtonUniDriver, InputUniDriver, CheckboxUniDriver, ButtonUniDriver } from '@wix/design-system/dist/testkit/unidriver';
import { dataHook } from 'wix-rich-content-common';
import { toHexFormat } from 'ricos-styles';

const SWATCHES = "color-swatches";
const SWATCH = "color-swatches-swatch";
const ADD_CUSTOM_COLOR_BUTTON = "add-custom-color-button";
const RESET_COLOR_BUTTON = "reset-color-button";

var __defProp$1 = Object.defineProperty;
var __defProps$1 = Object.defineProperties;
var __getOwnPropDescs$1 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1 = Object.getOwnPropertySymbols;
var __hasOwnProp$1 = Object.prototype.hasOwnProperty;
var __propIsEnum$1 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1 = (obj, key, value) => key in obj ? __defProp$1(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1.call(b, prop))
      __defNormalProp$1(a, prop, b[prop]);
  if (__getOwnPropSymbols$1)
    for (var prop of __getOwnPropSymbols$1(b)) {
      if (__propIsEnum$1.call(b, prop))
        __defNormalProp$1(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$1 = (a, b) => __defProps$1(a, __getOwnPropDescs$1(b));
const createColorSwatchesUnidriver = (getBase) => {
  const getSwatchesBase = async () => getBase().get(dataHook(SWATCHES));
  const getSwatch = async (index) => {
    const swatches = await getSwatchesBase();
    return swatches.$$(dataHook(SWATCH)).get(index);
  };
  return {
    addCustomColorButton: FillButtonUniDriver(
      getBase().$(dataHook(ADD_CUSTOM_COLOR_BUTTON)),
      getBase()
    ),
    resetColorButton: FillButtonUniDriver(getBase().$(dataHook(RESET_COLOR_BUTTON)), getBase()),
    getSwatch: async (index) => {
      const swatch = await getSwatch(index);
      return __spreadProps$1(__spreadValues$1({}, FillPreviewUniDriver(swatch, getBase())), {
        getColor: async () => {
          const el = await swatch.get(`button`);
          const style = await el._prop("style");
          return toHexFormat(style.getPropertyValue("background-color"));
        },
        getStyle: async () => {
          const el = await swatch.get(`button`);
          const style = await el._prop("style");
          return style;
        }
      });
    }
  };
};

const FLOATING_COLOR_SWATCHES = "floating-color-swatches";
const RESET_BUTTON = "reset-button";

const createFloatingColorPickerUniDriver = (getBase) => {
  return {
    exists: async () => {
      const modal = await getBase().$(dataHook(FLOATING_COLOR_SWATCHES));
      return modal.exists();
    },
    waitForElement: async () => {
      await getBase().get(dataHook(FLOATING_COLOR_SWATCHES));
    },
    swatches: createColorSwatchesUnidriver(getBase),
    resetButton: TextButtonUniDriver(getBase().$(dataHook(RESET_BUTTON)), getBase())
  };
};

const SWATCH_TOGGLE = "color-swatch-toggle";

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
const createToggledColorPickerUniDriver = (getBase) => {
  return {
    togglePicker: __spreadProps(__spreadValues({}, FillPreviewUniDriver(getBase().$(dataHook(SWATCH_TOGGLE)), getBase())), {
      getColor: async () => {
        const el = await getBase().get(`${dataHook(SWATCH_TOGGLE)} button`);
        const style = await el._prop("style");
        return toHexFormat(style.getPropertyValue("background-color"));
      },
      getStyle: async () => {
        const el = await getBase().get(`${dataHook(SWATCH_TOGGLE)} button`);
        const style = await el._prop("style");
        return style;
      }
    }),
    swatches: createColorSwatchesUnidriver(getBase)
  };
};

const LINK_PANEL_MODAL_LINK_INPUT = "linkPanelInput";
const LINK_SETTINGS_CHECKBOX_NEW_TAB = "linkPanelBlankCheckbox";
const LINK_SETTINGS_CHECKBOX_NOREFERRER = "linkPanelNoreferrerCheckbox";
const LINK_SETTINGS_CHECKBOX_NOFOLLOW = "linkPanelRelCheckbox";
const LINK_SETTINGS_CHECKBOX_SPONSORED = "linkPanelSponsoredCheckbox";

const createLinkSettingsUnidriver = (getBase) => {
  return {
    urlInput: InputUniDriver(getBase().$(dataHook(LINK_PANEL_MODAL_LINK_INPUT)), getBase()),
    openInNewTabCheckbox: CheckboxUniDriver(
      getBase().$(dataHook(LINK_SETTINGS_CHECKBOX_NEW_TAB)),
      getBase()
    ),
    noReferrerCheckbox: CheckboxUniDriver(
      getBase().$(dataHook(LINK_SETTINGS_CHECKBOX_NOREFERRER)),
      getBase()
    ),
    noFollowCheckbox: CheckboxUniDriver(
      getBase().$(dataHook(LINK_SETTINGS_CHECKBOX_NOFOLLOW)),
      getBase()
    ),
    sponsoredCheckbox: CheckboxUniDriver(
      getBase().$(dataHook(LINK_SETTINGS_CHECKBOX_SPONSORED)),
      getBase()
    )
  };
};

const CANCEL_BUTTON = "actionButtonCancel";
const SAVE_BUTTON = "actionButtonSave";

const createFooterActionsUnidriver = (getBase) => {
  return {
    saveButton: ButtonUniDriver(getBase().$(dataHook(SAVE_BUTTON)), getBase()),
    cancelButton: ButtonUniDriver(getBase().$(dataHook(CANCEL_BUTTON)), getBase())
  };
};

export { createFloatingColorPickerUniDriver, createFooterActionsUnidriver, createLinkSettingsUnidriver, createToggledColorPickerUniDriver };
//# sourceMappingURL=testkit.js.map
